using System;
using System.Collections.Generic;
using System.IO;
using System.Reflection;
using System.Runtime.Serialization;
using System.Text;
using System.Xml;
using System.Xml.Serialization;

using NUnit.Framework;

[Serializable]
[XmlRoot ("rsp", IsNullable = false)]
public class XmlResult<T> {
	[XmlAttribute ("stat")]
	public int StatusCode { get; set; }

	[XmlElement ("photos")]
	[XmlElement ("photosets")]
	public T Result { get; set; }
}

[Serializable]
[XmlRoot ("rsp")]
public class XmlField<T> {
	[XmlElement ("photos")]
	[XmlElement ("photosets")]
	public T Result;
}

[TestFixture]
public class XmlSerializationTest {

	[Test]
	public void GenericProperty_Bug5543 ()
	{
		XmlResult<string> r = new XmlResult<string> ();
		r.Result = "5543";
		r.StatusCode = 10;

		var serializer = new XmlSerializer (typeof (XmlResult<string>));
		using (var ms = new MemoryStream ()) {
			serializer.Serialize (ms, r);
			r.Result = String.Empty;
			r.StatusCode = -1;

			ms.Position = 0;
			XmlResult<string> back = (XmlResult<string>) serializer.Deserialize (ms);

			Assert.That (back.Result, Is.EqualTo ("5543"), "Result");
			Assert.That (back.StatusCode, Is.EqualTo (10), "StatusCode");
		}
	}
}

class C {
	static void Main ()
	{
		new XmlSerializationTest ().GenericProperty_Bug5543 ();
	}
}